@@ -108,11 +108,11 @@ def loadSyntax(gdx, onmulti = True):
 
 class FromDB:
 	@staticmethod
-	def declare(db, exceptions = None):
-		return ''.join([getattr(FromDB, f'decl{k}')(db, exceptions=exceptions) for k in ('Sets','Pars','Vars')])
+	def declare(db, exceptions = None, types = None):
+		return ''.join([getattr(FromDB, f'decl{k}')(db, exceptions=exceptions) for k in noneInit(types, ('Sets','Pars','Vars'))])
 	@staticmethod
-	def load(db, gdx = None, onmulti=True, exceptions_load=None):
-		return ''.join([getattr(FromDB, f'load{k}')(db, gdx = gdx, onmulti=onmulti, exceptions_load=None) for k in ('Sets','Pars','Vars')])
+	def load(db, gdx = None, onmulti=True, exceptions_load=None, types = None):
+		return ''.join([getattr(FromDB, f'load{k}')(db, gdx = gdx, onmulti=onmulti, exceptions_load=None) for k in noneInit(types, ('Sets','Pars','Vars'))])
 	@staticmethod
 	def declSets(db, exceptions = None):
 		return FromDB.declSets_(db, exceptions = exceptions)+FromDB.declAlias(db, exceptions = exceptions)+FromDB.declSetsOther(db, exceptions = exceptions)
@@ -134,9 +134,12 @@ class FromDB:
 
 	@staticmethod
 	def loadSyms(db, getTypes, gdx = None, onmulti=True, exceptions_load=None):
-		itersym = [f"$load {s}" for s in OrdSet(getTypes)-OrdSet(exceptions_load)]
-		start, end = loadSyntax(gdx, onmulti=onmulti)
-		return strBlock(start, itersym, joinby = '\n', end = end)
+		if getTypes:
+			itersym = [f"$load {s}" for s in OrdSet(getTypes)-OrdSet(exceptions_load)]
+			start, end = loadSyntax(gdx, onmulti=onmulti)
+			return strBlock(start, itersym, joinby = '\n', end = end)
+		else:
+			return ""
 	@staticmethod
 	def loadSets(db, gdx = None, **kwargs):
 		return FromDB.loadSyms(db, list(db.getTypes(['set']))+list(db.getTypes(['subset','map'])), gdx =gdx, **kwargs)
